def say_hello(name):
    github_pat = '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'
    aws_access_key = 'AKIAYZZGSY75LDOLKSUF'
    aws_secret_key = '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'
    return f"Hello, {name}!"



from setuptools import setup, find_packages

setup(
    name='pythongardenerpersonalpkg',
    version='0.3',
    packages=find_packages(),
    description='A simple example package',
    author='Your Name',
    author_email='your.email@example.com',
    url='https://github.com/yourusername/pythongardenerpersonalpkg',  # Optional
    install_requires=[],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
